<?php declare(strict_types=1);


namespace Pinpoint\DropShipping\Model;

use Magento\Framework\Api\DataObjectHelper;
use Pinpoint\DropShipping\Api\Data\DropShipItemInterface;
use Pinpoint\DropShipping\Api\Data\DropShipItemInterfaceFactory;
use Pinpoint\DropShipping\Model\Config\Source\Status;
use Pinpoint\DropShipping\Model\Data\Supplier;
use Magento\Sales\Model\Order\Item;

class DropShipItem extends \Magento\Framework\Model\AbstractModel
{

    protected $dropshipitemDataFactory;

    protected $dataObjectHelper;

    protected $_eventPrefix = 'pinpoint_dropshipping_dropshipitem';

    /**
     * @param \Magento\Framework\Model\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param DropShipItemInterfaceFactory $dropshipitemDataFactory
     * @param DataObjectHelper $dataObjectHelper
     * @param \Pinpoint\DropShipping\Model\ResourceModel\DropShipItem $resource
     * @param \Pinpoint\DropShipping\Model\ResourceModel\DropShipItem\Collection $resourceCollection
     * @param array $data
     */
    public function __construct(
        \Magento\Framework\Model\Context $context,
        \Magento\Framework\Registry $registry,
        DropShipItemInterfaceFactory $dropshipitemDataFactory,
        DataObjectHelper $dataObjectHelper,
        \Pinpoint\DropShipping\Model\ResourceModel\DropShipItem $resource,
        \Pinpoint\DropShipping\Model\ResourceModel\DropShipItem\Collection $resourceCollection,
        array $data = []
    ) {
        $this->dropshipitemDataFactory = $dropshipitemDataFactory;
        $this->dataObjectHelper = $dataObjectHelper;
        parent::__construct($context, $registry, $resource, $resourceCollection, $data);
    }

    /**
     * Retrieve dropshipitem model with dropshipitem data
     * @return DropShipItemInterface
     */
    public function getDataModel()
    {
        $dropshipitemData = $this->getData();

        $dropshipitemDataObject = $this->dropshipitemDataFactory->create();
        $this->dataObjectHelper->populateWithArray(
            $dropshipitemDataObject,
            $dropshipitemData,
            DropShipItemInterface::class
        );

        return $dropshipitemDataObject;
    }

    public function setDropshippingData(\Magento\Sales\Api\Data\OrderItemInterface $orderItem, Supplier $supplier)
    {
        $this->setItemId($orderItem->getId());
        $this->setOrderId($orderItem->getOrderId());
        $this->setProductName($orderItem->getName());
        $this->setSku($orderItem->getSku());
        $this->setSupplierId($supplier->getSupplierId());
        $this->setSupplierName($supplier->getCode());
        $this->setMethod($supplier->getMethod());
        $this->setStatus(Status::PENDING);

        return $this;
    }
}

